@@ -1,5 +1,5 @@
 package Treex::Block::Read::CoNLLX;
-$Treex::Block::Read::CoNLLX::VERSION = '0.13095';
+$Treex::Block::Read::CoNLLX::VERSION = '2.20151102';
 use strict;
 use warnings;
 use Moose;
@@ -7,6 +7,10 @@ use Treex::Core::Common;
 use File::Slurp;
 extends 'Treex::Block::Read::BaseCoNLLReader';
 
+has feat_is_iset => ( is => 'rw', isa => 'Bool', default => 0 );
+
+has deprel_is_afun => ( is => 'rw', isa => 'Bool', default => 0 );
+
 sub next_document {
     my ($self) = @_;
     my $text = $self->next_document_text();
@@ -21,6 +25,9 @@ sub next_document {
         my $bundle  = $document->create_bundle();
         my $zone    = $bundle->create_zone( $self->language, $self->selector );
         my $aroot   = $zone->create_atree();
+        if ( $self->deprel_is_afun ) {
+            $aroot->set_afun('AuxS');
+        }
         my @parents = (0);
         my @nodes   = ($aroot);
         my $sentence;
@@ -35,8 +42,18 @@ sub next_document {
             $newnode->set_conll_cpos($cpos);
             $newnode->set_conll_pos($pos);
             $newnode->set_conll_feat($feat);
+            if ( $self->feat_is_iset ) {
+                $newnode->set_iset_conll_feat($feat);
+            }
             $newnode->set_conll_deprel($deprel);
-            $sentence .= "$form ";
+            if ( $self->deprel_is_afun ) {
+                if ( $deprel =~ /_M$/ ) {
+                    $newnode->set_is_member(1);
+                    $deprel =~ s/_M$//;
+                }
+                $newnode->set_afun($deprel);
+            }
+            $sentence .= "$form " if(defined($form));
             push @nodes,   $newnode;
             push @parents, $head;
         }
@@ -60,7 +77,7 @@ Treex::Block::Read::CoNLLX
 
 =head1 VERSION
 
-version 0.13095
+version 2.20151102
 
 =head1 DESCRIPTION
 
@@ -68,9 +85,11 @@ Document reader for CoNLL format.
 Each token is on separated line in the following format:
 ord<tab>form<tab>lemma<tab>cpos<tab>pos<tab>features<tab>head<tab>deprel
 Sentences are separated with blank line.
-The sentences are stored into L<bundles|Treex::Core::Bundle> in the 
+The sentences are stored into L<bundles|Treex::Core::Bundle> in the
 L<document|Treex::Core::Document>.
 
+See L<http://ilk.uvt.nl/conll/#dataformat>.
+
 =head1 ATTRIBUTES
 
 =over
@@ -83,6 +102,20 @@ space or comma separated list of filenames
 
 number of sentences (!) per document
 
+=item feat_is_iset
+
+C<1> if the features field is a serialization of Interset
+(e.g. C<pos=adj|prontype=dem|number=plu|case=dat|person=3>)
+to read it directly into the Interset represenation for each node.
+C<0> by default.
+
+=item deprel_is_afun
+
+C<1> if the deprel field is an afun (e.g. C<Sb>, C<Obj_M>, C<Pnom>)
+to read it directly into the C<afun> field for each node
+(also strips C<_M> and sets C<is_member> to C<1>).
+C<0> by default.
+
 =back
 
 =head1 METHODS
