@@ -1,5 +1,5 @@
 package Treex::Block::W2A::ResegmentSentences;
-$Treex::Block::W2A::ResegmentSentences::VERSION = '0.13095';
+$Treex::Block::W2A::ResegmentSentences::VERSION = '2.20151102';
 use strict;
 use warnings;
 use Moose;
@@ -10,7 +10,7 @@ has remove => (
     is => 'ro',
     isa => enum( [qw(no all diff)] ),
     default => 'no',
-    documentation => 'remove=no   ... Do not delete any bundles (default). ' 
+    documentation => 'remove=no   ... Do not delete any bundles (default). '
                    . 'remove=all  ... Delete bundles with multiple subsegments. '
                    . 'remove=diff ... Delete bundles with zones with different number of subsegments.',
 );
@@ -30,7 +30,11 @@ sub _get_segmenter {
     my $specific = "Treex::Tool::Segment::${lang}::RuleBased";
     my $fallback = "Treex::Tool::Segment::RuleBased";
     foreach my $class ( $specific, $fallback ) {
-        my $segmenter = eval "use $class; $class->new()"; ##no critic (BuiltinFunctions::ProhibitStringyEval) We want to use it, it is simpler and we check result
+        my $segmenter;
+        {
+            local $SIG{"__DIE__"};
+            $segmenter = eval "use $class; $class->new()"; ##no critic (BuiltinFunctions::ProhibitStringyEval) We want to use it, it is simpler and we check result
+        }
         if ($segmenter) {
             $self->segmenters->{$lang} = $segmenter;
             return $segmenter;
@@ -67,7 +71,7 @@ sub process_bundle {
     # We are finished if
     # the zone to be processed contains just one sentence.
     return if $my_segments == 1;
-    
+
     # So we have more subsegments. Delete the bundle and exit if requested.
     if ($self->remove eq 'all'){
         $bundle->remove();
@@ -135,7 +139,7 @@ Treex::Block::W2A::ResegmentSentences - split bundles which contain more sentenc
 
 =head1 VERSION
 
-version 0.13095
+version 2.20151102
 
 =head1 MOTIVATION
 
