@@ -1,5 +1,5 @@
 package Treex::Block::W2A::Tokenize;
-$Treex::Block::W2A::Tokenize::VERSION = '0.13095';
+$Treex::Block::W2A::Tokenize::VERSION = '2.20151102';
 use strict;
 use warnings;
 use utf8;
@@ -18,17 +18,22 @@ override 'tokenize_sentence' => sub {
     $sentence =~ s/$/ /;
     $sentence =~ s/^/ /;
 
+    # The following characters (double-characters) are separated everywhere and cannot be used inside URLs.
+    # It is quite common than an URL is enclosed in quotes
+    # and URI::Find::Schemeless does not recognize such URLs, so we need to separate it first.
+    $sentence =~ s/(["<>{}“”«»–|—„‚‘]|\[|\]|``|\'\'|‘‘|\^)/ $1 /g;
+
     # detect web sites and email addresses and protect them from tokenization
     $sentence = $self->_mark_urls($sentence);
 
-    # the following characters (double-characters) are separated everywhere
-    $sentence =~ s/(;|!|<|>|\{|\}|\[|\]|\(|\)|\?|\#|\$|£|\%|\&|``|\'\'|‘‘|"|“|”|«|»|--|–|—|„|‚|‘|\*|\^|\|)/ $1 /g; ## no critic (RegularExpressions::ProhibitComplexRegexes) this is not complex
+    # the following characters (double-characters) are separated everywhere (except inside URLs)
+    $sentence =~ s/([;!()?#\$£%&*…]|--)/ $1 /g;
 
     # short hyphen is separated if it is followed or preceeded by non-alphanuneric character and is not a part of --, or a unary minus
     $sentence =~ s/([^\-\w])\-([^\-0-9])/$1 - $2/g;
     $sentence =~ s/([0-9]\s+)\-([0-9])/$1 - $2/g; # preceded by a number - not a unary minus
     $sentence =~ s/([^\-])\-([^\-\w])/$1 - $2/g;
-    
+
     # plus is separated everywhere, except at the end of a word (separated by a space) and as unary plus
     $sentence =~ s/(\w)\+(\w)/$1 + $2/g;
     $sentence =~ s/([0-9]\s*)\+([0-9])/$1 + $2/g;
@@ -56,23 +61,29 @@ override 'tokenize_sentence' => sub {
     return $sentence;
 };
 
-has _urls => ( is => 'rw' );
+use URI::Find::Schemeless;
+my @urls;
+my $finder = URI::Find::Schemeless->new(sub {
+    my ($uri, $orig_uri) = @_;
+    push @urls, $orig_uri;
+    return 'XXXURLXXX';
+});
 
 # internally marks URLs, so they won't be splitted
 sub _mark_urls {
     my ( $self, $sentence ) = @_;
-    my @urls;
-    while ( $sentence =~ s/(\W)((http:\/\/)?([\w\-]+\.)+(com|cz|de|es|eu|fr|hu|it|sk))(\W)/$1 XXXURLXXX $6/ ) { ## no critic (RegularExpressions::ProhibitComplexRegexes) this is not complex
-        push @urls, $2;
-    }
-    $self->_set_urls( \@urls );
+    @urls = ();
+    # URI::Find::Schemeless cannot detect URLs which are not preceded by a space (or beggining of string).
+    # Various types of brackets were already separated, but it is possible to find e.g. "go to:http://mysite.com"
+    # without the space after colon (or comma, or other word). Let's detect such URLs as well.
+    $sentence =~ s{(?<!\s)(https?://|www\.)}{ $1}g;
+    $finder->find(\$sentence);
     return $sentence;
 }
 
 # pushes bask URLs, marked by C<_mark_urls>
 sub _restore_urls {
     my ( $self, $sentence ) = @_;
-    my @urls = @{ $self->_urls };
     while (@urls) {
         my $url = shift @urls;
         $sentence =~ s/XXXURLXXX/$url/;
@@ -92,7 +103,7 @@ Treex::Block::W2A::Tokenize - language independent rule based tokenizer
 
 =head1 VERSION
 
-version 0.13095
+version 2.20151102
 
 =head1 DESCRIPTION
 
